@@ -22,7 +22,7 @@ class BlogPost(Displayable, Ownable, RichText, AdminThumbMixin):
     comments = CommentsField(verbose_name=_("Comments"))
     rating = RatingField(verbose_name=_("Rating"))
     featured_image = FileField(verbose_name=_("Featured Image"),
-                               upload_to="blog", extensions="Image",
+                               upload_to="blog", format="Image",
                                max_length=255, null=True, blank=True)
 
     admin_thumb_field = "featured_image"
