@@ -84,7 +84,6 @@ if "south" in settings.INSTALLED_APPS:
     try:
         from south.modelsinspector import add_introspection_rules
         add_introspection_rules(rules=[((FileField, RichTextField,), [], {})],
-            patterns=["mezzanine\.core\.fields\.",
-                      "mezzanine\.generic\.fields\."])
+                                patterns=["mezzanine\.core\.fields\."])
     except ImportError:
         pass
