@@ -1,19 +1,24 @@
 
 import os
 from shutil import rmtree
+from urlparse import urlparse
 from uuid import uuid4
 
 from django.contrib.auth.models import User
+from django.contrib.auth.tokens import default_token_generator
 from django.contrib.contenttypes.models import ContentType
+from django.core import mail
 from django.core.urlresolvers import reverse
 from django.db import connection
 from django.template import Context, Template, TemplateDoesNotExist
 from django.template.loader import get_template
 from django.test import TestCase
 from django.utils.html import strip_tags
+from django.utils.http import int_to_base36
 from django.contrib.sites.models import Site
 from PIL import Image
 
+from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
 from mezzanine.blog.models import BlogPost
 from mezzanine.conf import settings, registry
 from mezzanine.conf.models import Setting
@@ -47,13 +52,66 @@ class Tests(TestCase):
         args = (self._username, "example@example.com", self._password)
         self._user = User.objects.create_superuser(*args)
 
+    def account_data(self, test_value):
+        """
+        Returns a dict with test data for all the user/profile fields.
+        """
+        # User fields
+        data = {"email": test_value + "@example.com"}
+        for field in ("first_name", "last_name", "username",
+                      "password1", "password2"):
+            if field.startswith("password"):
+                value = "x" * settings.ACCOUNTS_MIN_PASSWORD_LENGTH
+            else:
+                value = test_value
+            data[field] = value
+        # Profile fields
+        Profile = get_profile_model()
+        if Profile is not None:
+            user_fieldname = get_profile_user_fieldname()
+            for field in Profile._meta.fields:
+                if field.name not in (user_fieldname, "id"):
+                    if field.choices:
+                        value = field.choices[0][0]
+                    else:
+                        value = test_value
+                    data[field.name] = value
+        return data
+
     def test_account(self):
         """
-        Test the account views.
+        Test account creation.
         """
-        if settings.ACCOUNTS_ENABLED:
-            response = self.client.get(reverse("account"))
-            self.assertEqual(response.status_code, 200)
+        # Verification not required - test an active user is created.
+
+        data = self.account_data("test1")
+        settings.ACCOUNTS_VERIFICATION_REQUIRED = False
+        response = self.client.post(reverse("signup"), data, follow=True)
+        self.assertEqual(response.status_code, 200)
+        users = User.objects.filter(email=data["email"], is_active=True)
+        self.assertEqual(len(users), 1)
+        # Verification required - test an inactive user is created,
+        settings.ACCOUNTS_VERIFICATION_REQUIRED = True
+        data = self.account_data("test2")
+        emails = len(mail.outbox)
+        response = self.client.post(reverse("signup"), data, follow=True)
+        self.assertEqual(response.status_code, 200)
+        users = User.objects.filter(email=data["email"], is_active=False)
+        self.assertEqual(len(users), 1)
+        # Test the verification email.
+        self.assertEqual(len(mail.outbox), emails + 1)
+        self.assertEqual(len(mail.outbox[0].to), 1)
+        self.assertEqual(mail.outbox[0].to[0], data["email"])
+        # Test the verification link.
+        new_user = users[0]
+        verification_url = reverse("signup_verify", kwargs={
+            "uidb36": int_to_base36(new_user.id),
+            "token": default_token_generator.make_token(new_user),
+        })
+        response = self.client.get(verification_url, follow=True)
+        self.assertEqual(response.status_code, 200)
+        users = User.objects.filter(email=data["email"], is_active=True)
+        self.assertEqual(len(users), 1)
 
     def test_draft_page(self):
         """
@@ -89,7 +147,7 @@ class Tests(TestCase):
         """
         description = "<p>How now brown cow</p>"
         page = RichTextPage.objects.create(title="Draft",
-                                          content=description * 3)
+                                           content=description * 3)
         self.assertEqual(page.description, strip_tags(description))
 
     def test_device_specific_template(self):
@@ -125,6 +183,16 @@ class Tests(TestCase):
                                             status=CONTENT_STATUS_PUBLISHED)
         response = self.client.get(blog_post.get_absolute_url())
         self.assertEqual(response.status_code, 200)
+        # Test the blog is login protected if its page has login_required
+        # set to True.
+        slug = settings.BLOG_SLUG or "/"
+        RichTextPage.objects.create(title="blog", slug=slug,
+                                    login_required=True)
+        response = self.client.get(reverse("blog_post_list"), follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertTrue(len(response.redirect_chain) > 0)
+        redirect_path = urlparse(response.redirect_chain[0][0]).path
+        self.assertEqual(redirect_path, settings.LOGIN_URL)
 
     def test_rating(self):
         """
