@@ -1,9 +1,7 @@
 
 from django.contrib.admin.views.decorators import staff_member_required
-from django.contrib.auth import REDIRECT_FIELD_NAME
-from django.http import HttpResponse
-from django.shortcuts import get_object_or_404, redirect
-from django.utils.http import urlquote
+from django.core.exceptions import ImproperlyConfigured
+from django.http import HttpResponse, Http404
 
 from mezzanine.conf import settings
 from mezzanine.pages import page_processors
@@ -48,34 +46,31 @@ admin_page_ordering = staff_member_required(admin_page_ordering)
 
 def page(request, slug, template="pages/page.html", extra_context=None):
     """
-    Display content for a page. First check for any matching page processors
-    and handle them. Secondly, build the list of template names to choose
-    from given the slug and type of page being viewed.
+    Select a template for a page and render it. The ``extra_context``
+    arg will include a ``page`` object that's added via
+    ``mezzanine.pages.middleware.PageMiddleware``. The page is loaded
+    via the middleware so that other apps with urlpatterns that match
+    the current page can include a page in their template context.
+    The urlpattern that maps to this view is a catch-all pattern, in
+    which case the page instance will be None, so raise a 404 then.
     """
-    page = get_object_or_404(Page.objects.published(request.user), slug=slug)
-    if page.login_required and not request.user.is_authenticated():
-        path = urlquote(request.get_full_path())
-        url = "%s?%s=%s" % (settings.LOGIN_URL, REDIRECT_FIELD_NAME, path)
-        return redirect(url)
-    context = {"page": page}
-    if extra_context is not None:
-        context.update(extra_context)
-    model_processors = page_processors.processors[page.content_model]
-    slug_processors = page_processors.processors["slug:%s" % page.slug]
-    for processor in model_processors + slug_processors:
-        response = processor(request, page)
-        if isinstance(response, HttpResponse):
-            return response
-        elif response:
-            try:
-                context.update(response)
-            except (TypeError, ValueError):
-                name = "%s.%s" % (processor.__module__, processor.__name__)
-                error = ("The page processor %s returned %s but must return "
-                         "HttpResponse or dict." % (name, type(response)))
-                raise ValueError(error)
-    templates = [u"pages/%s.html" % slug]
+    page_middleware = "mezzanine.pages.middleware.PageMiddleware"
+    if page_middleware not in settings.MIDDLEWARE_CLASSES:
+        raise ImproperlyConfigured(page_middleware + " is missing from " +
+                                   "settings.MIDDLEWARE_CLASSES")
+
+    extra_context = extra_context or {}
+    try:
+        page = extra_context["page"]
+    except KeyError:
+        raise Http404
+    # Check for a template name matching the page's slug. If the homepage
+    # is configured as a page instance, the template "pages/index.html" is
+    # used, since the slug "/" won't match a template name.
+    template_name = unicode(slug) if slug != "/" else "index"
+    templates = [u"pages/%s.html" % template_name]
+    # Check for a template matching the page's content model.
     if page.content_model is not None:
         templates.append(u"pages/%s.html" % page.content_model)
     templates.append(template)
-    return render(request, templates, context)
+    return render(request, templates, extra_context)
